@@ -5,13 +5,17 @@ import codecs
 import gzip
 import io
 import itertools
+import json
 import logging
-import lxml.etree
-import lxml.html
 import re
 import zlib
 
+import lxml.etree
+import lxml.html
+
+import wpull.decompression
 import wpull.http.util
+import wpull.string
 from wpull.thirdparty import robotexclusionrulesparser
 import wpull.util
 
@@ -144,7 +148,7 @@ class HTMLLightParserTarget(object):
             track of text.
     '''
     def __init__(self, callback,
-    text_elements=frozenset(['style', 'link', 'url', 'icon'])):
+    text_elements=frozenset(['style', 'script', 'link', 'url', 'icon'])):
         self.callback = callback
         self.text_elements = text_elements
         self.tag = None
@@ -334,7 +338,7 @@ class HTMLReader(BaseDocumentReader):
     @classmethod
     def is_file(cls, file):
         '''Return whether the file is likely to be HTML.'''
-        peeked_data = wpull.util.printable_bytes(
+        peeked_data = wpull.string.printable_bytes(
             wpull.util.peek_file(file)).lower()
 
         if b'<!doctype html' in peeked_data \
@@ -371,11 +375,11 @@ class HTMLReader(BaseDocumentReader):
             # NOTE: to_str is needed because on Python 2, byte strings may be
             # returned from lxml
             elements.append(HTMLReadElement(
-                wpull.util.to_str(tag),
-                wpull.util.to_str(dict(attrib))
+                wpull.string.to_str(tag),
+                wpull.string.to_str(dict(attrib))
                     if attrib is not None else None,
-                wpull.util.to_str(text),
-                wpull.util.to_str(tail),
+                wpull.string.to_str(text),
+                wpull.string.to_str(tail),
                 end
             ))
 
@@ -432,9 +436,15 @@ class HTMLReader(BaseDocumentReader):
         Returns:
             iterable: class:`HTMLReadElement`
         '''
+        parser_type = self.detect_parser_type(file, encoding=encoding)
+
+        if parser_type == 'xhtml':
+            # Use the HTML parser because there exists XHTML soup
+            parser_type = 'html'
+
         elements = self.read_tree(
             file, encoding=encoding, target_class=HTMLLightParserTarget,
-            parser_type=self.detect_parser_type(file, encoding=encoding)
+            parser_type=parser_type
         )
 
         return elements
@@ -451,13 +461,15 @@ class HTMLReader(BaseDocumentReader):
         else:
             lxml_encoding = encoding
 
-        parser = lxml.etree.XMLParser(encoding=lxml_encoding, recover=True)
-        tree = lxml.etree.parse(
-            io.BytesIO(wpull.util.peek_file(file)), parser=parser
-        )
-
-        if tree.getroot() is not None:
-            return wpull.util.to_str(tree.docinfo.doctype)
+        try:
+            parser = lxml.etree.XMLParser(encoding=lxml_encoding, recover=True)
+            tree = lxml.etree.parse(
+                io.BytesIO(wpull.util.peek_file(file)), parser=parser
+            )
+            if tree.getroot() is not None:
+                return wpull.string.to_str(tree.docinfo.doctype)
+        except lxml.etree.LxmlError:
+            pass
 
     @classmethod
     def detect_parser_type(cls, file, encoding=None):
@@ -503,6 +515,7 @@ class CSSReader(BaseDocumentReader):
             return True
 
         if response.body:
+            # Stylesheet mistakenly served as HTML
             if 'html' in response.fields.get('content-type', '').lower() \
             and cls.is_file(response.body.content_file):
                 return True
@@ -510,7 +523,7 @@ class CSSReader(BaseDocumentReader):
     @classmethod
     def is_file(cls, file):
         '''Return whether the file is likely CSS.'''
-        peeked_data = wpull.util.printable_bytes(
+        peeked_data = wpull.string.printable_bytes(
             wpull.util.peek_file(file)).lower()
 
         if b'<html' in peeked_data:
@@ -584,10 +597,105 @@ class CSSReader(BaseDocumentReader):
                 yield url_str_fragment.strip('"\'')
 
 
+class JavaScriptReader(BaseDocumentReader):
+    '''JavaScript Document Reader.'''
+    # Pattern based from https://github.com/internetarchive/heritrix3/
+    # blob/ffd248f7800dbd4bff1cf8afaa57a0a3e945ed85/modules/src/
+    # main/java/org/archive/modules/extractor/ExtractorJS.java
+    URL_PATTERN = r'''(\\{0,8}['"])(https?://[^'"]{1,500}|[^\s'"]{1,500})(?:\1)'''
+    BUFFER_SIZE = 1048576
+    STREAM_REWIND = 4096
+
+    @classmethod
+    def is_url(cls, url_info):
+        '''Return whether the document is likely to be JS.'''
+        if '.js' in url_info.path.lower():
+            return True
+
+    @classmethod
+    def is_request(cls, request):
+        '''Return whether the document is likely to be JS.'''
+        return cls.is_url(request.url_info)
+
+    @classmethod
+    def is_response(cls, response):
+        '''Return whether the document is likely to be JS.'''
+        if 'javascript' in response.fields.get('content-type', '').lower():
+            return True
+
+    @classmethod
+    def is_file(cls, file):
+        '''Return whether the file is likely JS.'''
+        peeked_data = wpull.string.printable_bytes(
+            wpull.util.peek_file(file)).lower()
+
+        if b'<html' in peeked_data:
+            return False
+
+        if re.search(br'var|function|setTimeout|jQuery\(',
+        peeked_data):
+            return True
+
+    def read_links(self, file, encoding=None):
+        '''Return an iterator of links found in the document.
+
+        Args:
+            file: A file object containing the document.
+            encoding (str): The encoding of the document.
+
+        Returns:
+            iterable: str
+        '''
+        stream = codecs.getreader(encoding or 'latin1')(file)
+        # stream = io.TextIOWrapper(file, encoding=encoding or 'latin1')
+        buffer = None
+
+        while True:
+            text = stream.read(self.BUFFER_SIZE)
+
+            if not text:
+                break
+
+            if not buffer and len(text) == self.BUFFER_SIZE:
+                buffer = io.StringIO()
+
+            if buffer:
+                buffer.write(text)
+                buffer.seek(0)
+
+                text = buffer.getvalue()
+
+            for link in self.scrape_links(text):
+                yield link
+
+            if buffer:
+                buffer.truncate()
+                buffer.write(text[:-self.STREAM_REWIND])
+
+    @classmethod
+    def scrape_links(cls, text):
+        '''Scrape any thing that might be a link.
+
+        Returns:
+            iterable: Each item is a str.
+        '''
+        text = re.sub(r'''(["'])([,;+])''', r'\1\2\n', text)
+
+        for match in re.finditer(cls.URL_PATTERN, text):
+            text = match.group(2)
+
+            if wpull.url.is_likely_link(text) \
+            and not wpull.url.is_unlikely_link(text):
+                try:
+                    yield json.loads('"{0}"'.format(text))
+                except ValueError:
+                    yield text
+
+
 class XMLDetector(BaseDocumentDetector):
     @classmethod
     def is_file(cls, file):
-        peeked_data = wpull.util.printable_bytes(
+        peeked_data = wpull.string.printable_bytes(
             wpull.util.peek_file(file)).lower()
 
         if b'<?xml' in peeked_data:
@@ -677,13 +785,13 @@ class SitemapReader(BaseDocumentReader):
 
         if is_gzip(peeked_data):
             try:
-                peeked_data = wpull.util.gzip_uncompress(
+                peeked_data = wpull.decompression.gzip_uncompress(
                     peeked_data, truncated=True
                 )
             except zlib.error:
                 pass
 
-        peeked_data = wpull.util.printable_bytes(peeked_data)
+        peeked_data = wpull.string.printable_bytes(peeked_data)
 
         if b'<?xml' in peeked_data \
         and (b'<sitemapindex' in peeked_data or b'<urlset' in peeked_data):
@@ -755,7 +863,7 @@ def get_heading_encoding(response):
         response.fields.get('content-type', ''))
 
     if encoding:
-        return wpull.util.normalize_codec_name(encoding)
+        return wpull.string.normalize_codec_name(encoding)
     else:
         return None
 
@@ -775,7 +883,7 @@ def detect_response_encoding(response, is_html=False, peek=131072):
         response.fields.get('content-type', '')
     )
 
-    encoding = wpull.util.detect_encoding(
+    encoding = wpull.string.detect_encoding(
         response.body.content_peek(peek), encoding=encoding, is_html=is_html
     )
 
