@@ -16,3 +16,6 @@ class TestFactory(unittest.TestCase):
         self.assertIn('dict', factory)
         self.assertEqual(my_instance, factory['dict'])
         self.assertTrue(factory.is_all_initialized())
+        self.assertEqual(1, len(factory))
+        self.assertEqual(['dict'], list(iter(factory)))
+        self.assertEqual(my_instance, factory.instance_map['dict'])
